@@ -84,30 +84,7 @@ CORE_API_MEDIA_TYPE = 'application/vnd.bihealth.sodar-core+json'
 CORE_API_DEFAULT_VERSION = re.match(
     r'^([0-9.]+)(?:[+|\-][\S]+)?$', core_version
 )[1]
-CORE_API_ALLOWED_VERSIONS = [
-    '0.7.2',
-    '0.8.0',
-    '0.8.1',
-    '0.8.2',
-    '0.8.3',
-    '0.8.4',
-    '0.9.0',
-    '0.9.1',
-    '0.10.0',
-    '0.10.1',
-    '0.10.2',
-    '0.10.3',
-    '0.10.4',
-    '0.10.5',
-    '0.10.6',
-    '0.10.7',
-    '0.10.8',
-    '0.10.9',
-    '0.10.10',
-    '0.10.11',
-    '0.10.12',
-    '0.10.13',
-]
+CORE_API_ALLOWED_VERSIONS = ['0.11.0']
 
 # Local constants
 INVALID_PROJECT_TYPE_MSG = (
@@ -398,7 +375,7 @@ class ProjectListAPIView(ListAPIView):
         Override get_queryset() to return projects of type PROJECT for which the
         requesting user has access.
         """
-        qs = Project.objects.filter(submit_status='OK').order_by('pk')
+        qs = Project.objects.all().order_by('pk')
 
         if self.request.user.is_superuser:
             return qs
@@ -426,7 +403,6 @@ class ProjectRetrieveAPIView(
     - ``public_guest_access``: Guest access for all users (boolean)
     - ``roles``: Project role assignments (dict, assignment UUID as key)
     - ``sodar_uuid``: Project UUID (string)
-    - ``submit_status``: Project creation status (string)
     - ``title``: Project title (string)
     - ``type``: Project type (string, options: ``PROJECT`` or ``CATEGORY``)
     """
@@ -484,7 +460,6 @@ class ProjectUpdateAPIView(
     - ``description``: Projcet description (string, optional)
     - ``readme``: Project readme (string, optional, supports markdown)
     - ``public_guest_access``: Guest access for all users (boolean)
-    - ``owner``: User UUID of the project owner (string)
     """
 
     permission_required = 'projectroles.update_project'
@@ -557,8 +532,7 @@ class RoleAssignmentDestroyAPIView(
 
     def perform_destroy(self, instance):
         """
-        Override perform_destroy() to handle RoleAssignment deletion with or
-        without SODAR Taskflow.
+        Override perform_destroy() to handle RoleAssignment deletion.
         """
         project = self.get_project()
 
